@@ -13,6 +13,9 @@ from fastadmin.settings import settings
 class BaseModelAdmin:
     """Base class for model admin"""
 
+    # Field name for representation of model instance (labels in selects)
+    repr_field = "id"
+
     # Not supported setting
     # actions
 
@@ -382,12 +385,12 @@ class BaseModelAdmin:
             return [f for f in model_fields if not self.exclude or f not in self.exclude]
         return [f for f in fields if f in model_fields]
 
-    def get_fieldsets(self) -> Sequence[tuple[str | None, dict[str, Sequence[str]]]]:
-        """This method is used to get fieldsets data for form view.
+    # def get_fieldsets(self) -> Sequence[tuple[str | None, dict[str, Sequence[str]]]]:
+    #     """This method is used to get fieldsets data for form view.
 
-        :return: A list of fieldsets data.
-        """
-        return self.fieldsets
+    #     :return: A list of fieldsets data.
+    #     """
+    #     return self.fieldsets
 
     def has_add_permission(self) -> bool:
         """This method is used to check if user has permission to add new model instance.
